Documentation — Django Grappelli 2.5.0 documentation

### Navigation

- index
- next |
- Django Grappelli 2.5.0 documentation »

# Documentation

A jazzy skin for the Django admin interface.

This documentation covers version 2.5.0 of Grappelli. Grappelli is a grid-based alternative/extension to the Django administration interface.

Note

Grappelli 2.5.0 requires Django 1.6. More on Versions and Compatibility.

## Installation & Setup

- Quick start guide
  - Installation
  - Setup
  - Testing
- Customization
  - Available Settings
  - Collapsibles
  - Inline Sortables
  - Sortable Excludes
  - Rearrange Inlines
  - Related Lookups
  - Autocomplete Lookups
  - Using TinyMCE
  - Changelist Templates
  - Changelist Filters
  - Switch User

## Dashboard

- Dashboard Setup
  - Add `grappelli.dashboard` to your installed apps
  - Add context processors
  - Create a custom dashboard
  - Create custom dashboards for multiple admin sites
- Dashboard API
  - The `Dashboard` class
  - The `DashboardModule` class
  - The `Group` class
  - The `LinkList` class
  - The `AppList` class
  - The `ModelList` class
  - The `RecentActions` class
  - The `Feed` class

## Internals

- Templates
- Javascripts
  - Original JS
  - Grappelli JS

## Help

- FAQ
- Best Practice
- Third Party Applications
- Troubleshooting
- Django Issues
- Grappelli 2.5.x Release Notes
- Changelog

## Code

https://github.com/sehmaschine/django-grappelli

## Website

http://www.grappelliproject.com

## Discussion

Use the Grappelli Google Group to ask questions or discuss features.

## Versions and Compatibility

Grappelli is always developed against the latest stable Django release and is NOT tested with Djangos trunk.

- Grappelli 2.5.0 (November 13th, 2013): Compatible with Django 1.6
- Grappelli 2.4.8 (November 12th, 2013): Compatible with Django 1.4/1.5

Current development branches:

- Grappelli 2.5.1 (Development version for Django 1.6, see branch Stable/2.5.x)
- Grappelli 2.4.9 (Development version for Django 1.4/1.5, see branch Stable/2.4.x)

Older versions are availabe at GitHub, but are not supported anymore.

### Navigation

- index
- next |
- Django Grappelli 2.5.0 documentation »